module  Graphics(
            
				//************************************************
				//This is the main module of the graphics subsystem
				//Each individual module has information about it's
				//operation in its own .v file. This module is the
				//"glue" that holds everything for CP2 together.
				//
				//Good Luck!!!
				//
				//Modify this code as needed, this is only a recommended format
				//
				//************************************************
				
				
				
				//-----------------------------------------------
            //  System Inputs
            //-----------------------------------------------
            Clock,
            CameraClock,
            Reset,
				Ready,
            //-----------------------------------------------

            //-----------------------------------------------
            //  Video Encoder I/O
            //-----------------------------------------------
            VE_P,           // Video data to the ADV7194
            VE_SCLK,        // I2C Clock
            VE_SDA,         // I2C Data
            VE_PAL_NTSC,    // PAL/NTSC Video Standard Select
            VE_RESET_B_,    // Reset out to ADV7194
            VE_HSYNC_B_,    // Unused
            VE_VSYNC_B_,    // Unused
            VE_BLANK_B_,    // Unused
            VE_SCRESET,     // Unused
            VE_CLKIN,       // Clock out to ADV7194
            //-----------------------------------------------

            //-----------------------------------------------
            //  Video Decoder I/O
            //-----------------------------------------------
            VD_LLC,
            VD_P,
            VD_SCLK,
            VD_SDA,
            VD_ISO,
            VD_RESET_B_,
            //-----------------------------------------------
				
				//-----------------------------------------------
				//	 Arbiter I/O Goes here
				//-----------------------------------------------
				

				
				
				
				
				
				
				/************************************************/
        );
    
    //---------------------------------------------------------------
    //  Parameters
    //---------------------------------------------------------------
    parameter   clockfreq       = 27000000,
                width           = 32,
                rawidth         = 13,
                cawidth         = 9,
                bawidth         = 2,
                burstlen        = 8,
                interleaved     = 0,
                totallines      = 525,
                activelines     = 507,
                f0topblank      = 6,
                hblanksamples   = 138,
                activesamples   = 720;
    //---------------------------------------------------------------
    
    //---------------------------------------------------------------
    //  Constants
    //---------------------------------------------------------------
    
    
    `ifdef MACROSAFE
    localparam  awidth       = `max(rawidth, cawidth),
                tawidth      = cawidth + rawidth + bawidth,
                ports        = 2,
                evenactive   = activelines >> 1,
                oddactive    = activelines - evenactive,
                rcbits       = `log2(oddactive),
                activebytes  = (activesamples * 2),
                activebursts = activebytes / (burstlen * (width / 8)),
                ccbits       = `log2(activebursts),
                apadbits     = tawidth-7-rcbits-ccbits;
    `endif
    //---------------------------------------------------------------

    //---------------------------------------------------------------
    //  System Inputs
    //---------------------------------------------------------------
    input           Clock;
    input           CameraClock;
    input           Reset;
	 input			  Ready;
    //---------------------------------------------------------------
	 
    
    //---------------------------------------------------------------
    //  Video Encoder I/O
    //---------------------------------------------------------------
    output  [9:0]   VE_P;
    inout           VE_SCLK, VE_SDA;
    output          VE_PAL_NTSC;
    output          VE_RESET_B_;
    output          VE_HSYNC_B_, VE_VSYNC_B_, VE_BLANK_B_;
    output          VE_SCRESET;
    output          VE_CLKIN;
    
    //---------------------------------------------------------------
    //  Video Decoder I/O
    //---------------------------------------------------------------
	 input   [2:1]   VD_LLC;
    input   [9:0]   VD_P;
    output          VD_SCLK;
    output          VD_SDA;
    output          VD_ISO;
    output          VD_RESET_B_;
	 
	 //---------------------------------------------------------------
	 //  Video Encoder/Decoder Signals
	 //---------------------------------------------------------------
	 
	 wire		[31:0]	DIn;						//Input to the Video Encoder. You need to retrieve this data from your SDRAM
	 wire					InRequest;
	 
	 wire		[31:0]	DataFromDecoder;		//Output from the Video Decoder. You need to store this into your SDRAM
	 wire					DataFromDecoderValid;
	 
	 wire		[8:0]		InRequestLine;
	 wire		[8:0]		InRequestPair;
	 
	 
	 /** Declare Ports to connect to your arbiter here */
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 /** Add Modules interfacing with your arbiter here */
	 

	
	
	
	
	
	
	
	
	
	
	 /****** DO NOT MODIFY BELOW THIS LINE ******/
	 //---------------------------------------------------------------
	 
	 
	
	 //---------------------------------------------------------------
	 //  Video Encoder
	 //---------------------------------------------------------------
	
    VideoEncoder 		VE(	  .VE_P(VE_P),                // Video data to the ADV7194
									  .VE_SCLK(VE_SCLK),          // I2C Clock
									  .VE_SDA(VE_SDA),            // I2C Data
									  .VE_PAL_NTSC(VE_PAL_NTSC),  // PAL/NTSC Video Standard Select
									  .VE_RESET_B_(VE_RESET_B_),  // Reset out to ADV7194
									  .VE_HSYNC_B_(VE_HSYNC_B_),  // Unused
									  .VE_VSYNC_B_(VE_VSYNC_B_),  // Unused
									  .VE_BLANK_B_(VE_BLANK_B_),  // Unused
									  .VE_SCRESET(VE_SCRESET),    // Unused
									  .VE_CLKIN(VE_CLKIN),        // Clock out to ADV7194
									  //-----------------------------------------------
							
									  //-----------------------------------------------
									  //	System Inputs
									  //-----------------------------------------------
									  .Clock(Clock),
									  .Reset(Reset || ~Ready), // should not ask for anything unless SDRAM is ready
									  //-----------------------------------------------
							
									  //-----------------------------------------------
									  //	Video Data Host Interface
									  //-----------------------------------------------
									  .DIn(DIn),
									  .InRequest(InRequest),
									  .InRequestLine(InRequestLine),  
									  .InRequestPair(InRequestPair),
									  .CycleCount (CycleCount),
									  .DisableSCLOp (DisableSCLOp),
									  .SDataEnable (SDataEnable),
									  .SData (SData)
									  
									  );
									  
	//Used to move tristate logic out of video encoder
	wire 		[6:0]		CycleCount;
	wire					DisableSCLOp;
	wire					SDataEnable;
	wire					SData;
	
	
	//---------------------------------------------------------------
	//	 Pullups
	//---------------------------------------------------------------
	// synthesis translate_off
	pullup		pscl(SCL);
	pullup		psda(SDA);
	// synthesis translate_on
	//---------------------------------------------------------------
	
	assign	VE_SCLK =			(CycleCount[6] | DisableSCLOp) ? 1'bz : 1'b0;
	assign	VE_SDA =				SDataEnable ? SData : 1'bz;

	//---------------------------------------------------------------
	//  Video Decoder
	//---------------------------------------------------------------
	VideoDecoder    	VD(  	  .CLK(CameraClock),
									  .RST(Reset),
									  .EN(Ready), //MemReady is used as a universal "Start" signal 
														  //because it takes the longest to initialize.
									  .P(VD_P),
									  .RST_OUT_(VD_RESET_B_),
									  .ISO(VD_ISO),
									  .SCLK(VD_SCLK),
									  .SDA(VD_SDA),
									  .SOF(VD_SOF),
									  .SEF(VD_SEF),
									  .EAV(VD_EAV),
									  .SAV(VD_SAV),
									  .VALID(DataFromDecoderValid),
									  .DATA_OUT(DataFromDecoder));

endmodule
