//-----------------------------------------------------------------------
//	File:		$RCSfile: VideoEncoder.v,v $
//	Version:	$Revision: 1.1 $
//	Desc:		ITU656/601 Video Encoder
//	Author:		Greg Gibeling
//	Copyright:	Copyright 2003 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Change Log
//-----------------------------------------------------------------------
//	$Log: VideoEncoder.v,v $
//	Revision 1.1  2004/10/05 19:56:01  SYSTEM
//	Initial Import
//	
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Includes
//-----------------------------------------------------------------------
`include "Const.v"
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		VideoEncoder
//	Desc:		This module will request pixel pairs from a host
//			once every four clock cycles during the active
//			video period.
//
//			The interface allows for synchronous read in that
//			it will expect data on the cycle after it makes
//			the request.
//
//			Pixels will be requested across each line and
//			then down across first the odd frame then
//			similarly across the even frame.  Note that line
//			adresses will be every-other-one due to this
//			interlacing.
//	Params:		totallines:	The total number of video lines
//					to output.
//			activelines:	The total number of active video
//					lines to output
//			f0topblank:	The number of vertical blanking
//					lines to insert above the active
//					portion of the 0 (Odd) field.
//			hblanksamples:	The number of samples (16bit
//					words) per line which are
//					blanking.  Includes SAV/EAV
//			activesamples:	The number of active video samples
//					per line.
//-----------------------------------------------------------------------
module	VideoEncoder(	//-----------------------------------------------
			//	Video Encoder I/O
			//-----------------------------------------------
			VE_P,		// Video data to the ADV7194
			VE_SCLK,	// I2C Clock
			VE_SDA,		// I2C Data
			VE_PAL_NTSC,	// PAL/NTSC Video Standard Select
			VE_RESET_B_,	// Reset out to ADV7194
			VE_HSYNC_B_,	// Unused
			VE_VSYNC_B_,	// Unused
			VE_BLANK_B_,	// Unused
			VE_SCRESET,	// Unused
			VE_CLKIN,	// Clock out to ADV7194
			//-----------------------------------------------

			//-----------------------------------------------
			//	System Inputs
			//-----------------------------------------------
			Clock,
			Reset,
			//-----------------------------------------------

			//-----------------------------------------------
			//	Video Data Host Interface
			//-----------------------------------------------
			DIn,
			InRequest,
			InRequestLine,
			InRequestPair,//,
			//TextMode,
			//TextWAddr, 
			//TextWData, 
			//ColorData,
			//TextWE,
			//-----------------------------------------------
			
			//Outputs to move tristate logic out
			CycleCount, 
			DisableSCLOp, 
			SDataEnable, 
			SData
		);


	output	[9:0]		VE_P;

	input				VE_SCLK;
	input				VE_SDA;
	
	output			VE_PAL_NTSC;
	output			VE_RESET_B_;
	output			VE_HSYNC_B_, VE_VSYNC_B_, VE_BLANK_B_;
	output			VE_SCRESET;
	output			VE_CLKIN;

	output 	[6:0]		CycleCount;
	output				DisableSCLOp;
	output 				SDataEnable;
	output 				SData;

	input			Clock, Reset;


	input		[31:0]		DIn;
	output				InRequest;
	output	[8:0]		InRequestLine;
	output	[8:0]		InRequestPair;
	

	//---------------------------------------------------------------
endmodule
//-----------------------------------------------------------------------